package com.jiuqi.util.hardware;

import com.jiuqi.util.JqLib;
import com.jiuqi.util.SortedList;
import com.jiuqi.util.StringUtils;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.UnsupportedEncodingException;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;

public final class HardwareUtil {
   private static final int CODE_SEED = 151;

   public static final String getMachineCode(String softFlag) throws Exception {
      String code = softFlag + "@" + getMacAddress();
      MessageDigest md5 = MessageDigest.getInstance("md5");
      byte[] data = md5.digest(code.getBytes());
      data = encodeData(data);
      String md5Data = JqLib.bytesToHexString(data);
      String machineCode = "";
      int i = false;

      int i;
      for(i = 0; i < md5Data.length() - 4; i += 4) {
         machineCode = machineCode + md5Data.substring(i, i + 4) + "-";
      }

      machineCode = machineCode + md5Data.substring(i, md5Data.length());
      return machineCode;
   }

   public static final byte[] getMachineSign(String category) {
      String macAddr;
      try {
         macAddr = getMacAddress();
         if (StringUtils.isEmpty(macAddr)) {
            return null;
         }
      } catch (Exception var8) {
         return null;
      }

      String code = category + "@" + macAddr;

      byte[] codeBytes;
      try {
         codeBytes = code.getBytes("UTF-8");
      } catch (UnsupportedEncodingException var7) {
         codeBytes = code.getBytes();
      }

      MessageDigest md5;
      try {
         md5 = MessageDigest.getInstance("MD5");
      } catch (NoSuchAlgorithmException var6) {
         return null;
      }

      byte[] data = md5.digest(codeBytes);
      return encodeData(data);
   }

   private static byte[] encodeData(byte[] data) {
      if (data == null) {
         return null;
      } else {
         int newSize = data.length / 2;
         byte[] result = new byte[newSize];

         for(int i = 0; i < newSize; ++i) {
            int a = data[i * 2];
            int b = data[i * 2 + 1];
            result[i] = (byte)(a ^ 151 + b ^ -152);
         }

         return result;
      }
   }

   public static String getMacAddress() throws Exception {
      String os = System.getProperty("os.name");
      if (os.startsWith("Windows")) {
         return getWindowsMacAddresses();
      } else if (os.startsWith("Linux")) {
         return getLinuxMacAddresses();
      } else {
         return os.startsWith("HP-UX") ? getHPUXMacAddresses() : "";
      }
   }

   private static String getWindowsMacAddresses() throws IOException {
      String ipCommandResponse = windowsRunIpConfigCommand();
      return windowsParseMacAddress(ipCommandResponse);
   }

   private static String windowsRunIpConfigCommand() throws IOException {
      Process p = Runtime.getRuntime().exec("ipconfig /all");
      return readInputText(p);
   }

   private static String readInputText(Process p) throws IOException {
      StringBuffer buffer = new StringBuffer();
      BufferedReader reader = new BufferedReader(new InputStreamReader(p.getInputStream()));

      String line;
      while((line = reader.readLine()) != null) {
         buffer.append(line);
         buffer.append(StringUtils.LINE_SEPARATOR);
      }

      return buffer.toString();
   }

   private static String windowsParseMacAddress(String ipConfigResponse) {
      StringTokenizer stringTokenizer = new StringTokenizer(ipConfigResponse, "\n");
      SortedList buffer = new SortedList();

      while(true) {
         String line;
         do {
            if (!stringTokenizer.hasMoreTokens()) {
               return catMacAddrs(buffer);
            }

            line = stringTokenizer.nextToken().trim();
         } while(!line.startsWith("Physical") && !line.startsWith("物理地址"));

         int p = line.lastIndexOf(58);
         String macAddr = p + 1 >= line.length() ? null : line.substring(p + 1).trim();
         if (!StringUtils.isEmpty(macAddr) && !buffer.contains(macAddr)) {
            buffer.add(macAddr);
         }
      }
   }

   private static String catMacAddrs(List buffer) {
      if (buffer.size() == 0) {
         return null;
      } else {
         StringBuffer result = new StringBuffer((String)buffer.get(0));

         for(int i = 1; i < buffer.size(); ++i) {
            result.append(';').append(((String)buffer.get(i)).toUpperCase());
         }

         return result.toString();
      }
   }

   private static String getLinuxMacAddresses() throws Exception {
      String ifCommandResponse = linuxRunIfConfigCommand();
      return linuxParseMacAddress(ifCommandResponse);
   }

   private static String linuxRunIfConfigCommand() throws IOException {
      Process p = Runtime.getRuntime().exec("ifconfig");
      return readInputText(p);
   }

   private static String linuxParseMacAddress(String ifCommandResponse) {
      StringTokenizer stringTokenizer = new StringTokenizer(ifCommandResponse, "\n");
      SortedList buffer = new SortedList();

      while(stringTokenizer.hasMoreTokens()) {
         String line = stringTokenizer.nextToken();
         int macPos = line.indexOf("HWaddr");
         if (macPos != -1) {
            String macAddr = line.substring(macPos + 1).trim();
            if (macAddr.length() == 17 && !buffer.contains(macAddr)) {
               buffer.add(macAddr);
            }
         }
      }

      return catMacAddrs(buffer);
   }

   private static String getHPUXMacAddresses() throws IOException {
      String lanscanCommandResponse = hpUXRunLanscanCommmand();
      return hpUXParseMacAddress(lanscanCommandResponse);
   }

   private static String hpUXRunLanscanCommmand() throws IOException {
      Process p = Runtime.getRuntime().exec("lanscan");
      return readInputText(p);
   }

   private static String hpUXParseMacAddress(String lanscanCommandResponse) {
      StringTokenizer stringTokenizer = new StringTokenizer(lanscanCommandResponse, "\n");
      ArrayList buffer = new ArrayList();

      while(stringTokenizer.hasMoreTokens()) {
         String line = stringTokenizer.nextToken().trim();
         int index = line.indexOf("0x");
         if (index != -1) {
            String macAddr = line.substring(index + 2, index + 2 + 12);
            if (!buffer.contains(macAddr)) {
               buffer.add(macAddr);
            }
         }
      }

      return catMacAddrs(buffer);
   }
}
